#include "guile-gtk.h"

int
main (void)
{
  sgtk_init ();
  return 0;
}
